@@ -32,12 +32,14 @@ try:
     from htmlwidgets import HtmlFrame, HtmlLabel
     from utilities import Notebook
 except (ImportError, ModuleNotFoundError):
+    import traceback
     # Give useful troubleshooting information as a popup, as most bundled applications don't have a visible console
     # Also print the message in case something is wrong with the Tkinter installation as well
     error_message = "ModuleNotFoundError: The files required to run TkinterWeb could not be found. \
 This usually occurs when bundling TkinterWeb into an app without forcing the application maker to include all nessessary files. \
 See https://github.com/Andereoo/TkinterWeb/blob/main/tkinterweb/docs/FAQ.md for more information."
-    sys.stdout.write(error_message+"\n\n")
+    sys.stdout.write("{}\n\nError: {}\n\nIf you think this is a bug, please file a bug report at https://github.com/Andereoo/TkinterWeb.".format(error_message, traceback.format_exc()))
+    
     try:
         import tkinter as tk
         from tkinter import messagebox
@@ -46,7 +48,7 @@ See https://github.com/Andereoo/TkinterWeb/blob/main/tkinterweb/docs/FAQ.md for
         import tkMessageBox as messagebox
     root = tk.Tk()
     root.withdraw()
-    message = messagebox.showerror("Fatal Error Encountered", error_message)
+    message = messagebox.showerror("Fatal Error Encountered", error_message) #for older versions of pyinstaller, windowed app may crash without any message of any kind
     sys.exit()
 
 
